@@ -1,4 +1,4 @@
--- AI-Mem Database Initialization Script
+-- mem8 Database Initialization Script
 -- This script sets up initial database configuration for PostgreSQL
 
 -- Enable UUID extension
@@ -9,8 +9,8 @@ CREATE EXTENSION IF NOT EXISTS "uuid-ossp";
 -- but ensures we have proper permissions and extensions
 
 -- Grant necessary permissions
-GRANT ALL PRIVILEGES ON DATABASE aimem TO aimem_user;
-GRANT ALL PRIVILEGES ON DATABASE aimem_dev TO dev_user;
+GRANT ALL PRIVILEGES ON DATABASE mem8 TO mem8_user;
+GRANT ALL PRIVILEGES ON DATABASE mem8_dev TO dev_user;
 
 -- Set timezone
 SET timezone = 'UTC';
\ No newline at end of file
