@@ -1,4 +1,4 @@
-"""API routers for AI-Mem backend."""
+"""API routers for mem8 backend."""
 
 __all__ = [
     "health",
