@@ -136,7 +136,7 @@ export default function Home() {
 
   const handleLocalMode = () => {
     // Set a local storage flag to indicate we're using local mode
-    localStorage.setItem('ai-mem-local-mode', 'true');
+    localStorage.setItem('mem8-local-mode', 'true');
     // Refresh to re-evaluate authentication state
     window.location.reload();
   };
@@ -208,7 +208,7 @@ export default function Home() {
       <div className="min-h-screen bg-black text-green-400 font-mono flex items-center justify-center">
         <div className="max-w-md w-full text-center space-y-4">
           <div className="text-2xl font-bold">
-            &gt; AI-MEM TERMINAL
+            &gt; mem8 TERMINAL
           </div>
           
           <div className="space-y-4">
